@@ -299,15 +299,22 @@ lme.formula <-
   numIter <- 0
   repeat {
     oldPars <- coef(lmeSt)
-    aNlm <- optim(fn = function(lmePars) -logLik(lmeSt, lmePars),
-                  par = c(coef(lmeSt)),
-                  method = "BFGS",
-                  control = list(trace = controlvals$msVerbose,
-                  reltol = if(numIter == 0) controlvals$msTol
-                           else 100*.Machine$double.eps,
-                  maxit = controlvals$msMaxIter))
+    optRes <- if (exists("nlminb", mode = "function")) {
+        nlminb(c(coef(lmeSt)),
+               function(lmePars) -logLik(lmeSt, lmePars),
+               control = list(iter.max = controlvals$msMaxIter,
+               trace = controlvals$msVerbose))
+    } else {
+        optim(c(coef(lmeSt)),
+              function(lmePars) -logLik(lmeSt, lmePars),
+              control = list(trace = controlvals$msVerbose,
+              maxit = controlvals$msMaxIter,
+              reltol = if(numIter == 0) controlvals$msTol
+              else 100*.Machine$double.eps),
+              method = "BFGS")
+    }
     numIter0 <- NULL
-    coef(lmeSt) <- aNlm$par
+    coef(lmeSt) <- optRes$par
     attr(lmeSt, "lmeFit") <- MEestimate(lmeSt, grps)
     ## checking if any updating is needed
     if (!needUpdate(lmeSt)) break
@@ -416,6 +423,13 @@ getFixDF <-
     namTerms <- factor(assign, labels = namTerms)
     assign <- split(order(assign), namTerms)
   }
+  ## function to check if a vector is (nearly) a multiple of (1,1,...,1)
+  const <- function(x, tolerance = sqrt(.Machine$double.eps)) {
+      if (length(x) < 1) return(NA)
+      x <- as.numeric(x)
+      if (x[1] == 0.) return(all(abs(x) < tolerance))
+      all(abs((x/x[1] - 1.)) < tolerance)
+  }
   N <- nrow(X)
   p <- ncol(X)
   Q <- ncol(grps)
@@ -430,18 +444,18 @@ getFixDF <-
   namTerms <- names(assign)
   valTerms <- double(length(assign))
   names(valTerms) <- namTerms
-  if (any(notIntX <- apply(X, 2, function(el) any(el != el[1])))) {
-        ## percentage of groups for which columns of X are inner
-    innP <- array(c(rep(1, p),
-                    .C("inner_perc_table",
-                       as.double(X),
-                       as.integer(unlist(grps)),
-                       as.integer(p),
-                       as.integer(Q),
-                       as.integer(N),
-                       val = double(p * Q),
-                       PACKAGE = "nlme")[["val"]]), c(p, Qp1),
-                  list(namX, stratNam))
+  if (any(notIntX <- !apply(X, 2, const))) {
+      ## percentage of groups for which columns of X are inner
+      innP <- array(c(rep(1, p),
+                      .C("inner_perc_table",
+                         as.double(X),
+                         as.integer(unlist(grps)),
+                         as.integer(p),
+                         as.integer(Q),
+                         as.integer(N),
+                         val = double(p * Q),
+                         PACKAGE = "nlme")[["val"]]), c(p, Qp1),
+                    list(namX, stratNam))
     ## strata in which columns of X are estimated
     ## ignoring fractional inner percentages for now
     stratX <- stratNam[apply(innP, 1, function(el, index) max(index[el > 0]),
@@ -1787,7 +1801,7 @@ predict.lme <-
   }
   maxQ <- max(level)			# maximum level for predictions
   mCall <- object$call
-  fixed <- eval(mCall[["fixed"]][-2])
+  fixed <- eval(eval(mCall$fixed)[-2])
   newdata <- as.data.frame(newdata)
 
   if (maxQ > 0) {			# predictions with random effects
