@@ -1,25 +1,7 @@
-### $Id: simulate.R,v 1.6.2.1 2002/08/09 19:45:29 bates Exp $
-###
 ###            Fit a general linear mixed effects model
 ###
-### Copyright 1997-2001  Jose C. Pinheiro <jcp@research.bell-labs.com>,
+### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-###
-### This file is part of the nlme library for S and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
 
 createConLin <-
   function(fixed, data = sys.frame(sys.parent()),
@@ -494,24 +476,24 @@ plot.simulate.lme <-
   Mdf <- ordered(Mdf, levels = unique(Mdf))
   frm <- data.frame(x = c(MLx, REMLx)[auxInd], y = c(MLy, REMLy)[auxInd],
 		    df = Mdf,  method = meth)
-  names(frm$x) <- rep(1, nrow(frm))
-  if (df[1] == 0) {
-    names(frm$x)[substring(frm$df,1,3) == "Mix"] <- 1 - weights[1]
-    if (missing(ylim)) {
-      ylim <- c(0.0384, 1)
-    }
-  }
-  xyplot(form, data = frm,
-	 panel = function(x, y, ...) {
-           panel.grid()
-           panel.xyplot(x, y, type = "l", ...)
-           if ((dfType <- as.double(names(x)[1])) == 1) {
-             panel.abline( 0, as.double(names(x)[1]), lty = 2 )
-           } else {
-             panel.xyplot(c(0,dfType,dfType,1), c(0,dfType,1,1),
-                          type="l", lty = 2, col = 1)
-           }
-         },
+##  names(frm$x) <- rep(1, nrow(frm))
+##  if (df[1] == 0) {
+##    names(frm$x)[substring(frm$df,1,3) == "Mix"] <- 1 - weights[1]
+##    if (missing(ylim)) {
+##      ylim <- c(0.0384, 1)
+##    }
+##  }
+  xyplot(form, data = frm, type = c('g', 'l'),
+##	 panel = function(x, y, ...) {
+##           panel.grid()
+##           panel.xyplot(x, y, type = "l", ...)
+##           if ((dfType <- as.double(names(x)[1])) == 1) {
+##             panel.abline( 0, as.double(names(x)[1]), lty = 2 )
+##           } else {
+##             panel.xyplot(c(0,dfType,dfType,1), c(0,dfType,1,1),
+##                          type="l", lty = 2, col = 1)
+##           }
+##         },
 	 strip = strip, xlab = xlab, ylab = ylab, aspect = aspect,
          xlim = xlim, ylim = ylim, ...)
 }
